A fast gradient boosting framework on manifolds(from regression tree,classification tree,neural net....).

##### 1)Faster than LightGBM with same accuracy. 

##### 2)sklearn-like api interface.

##### 3)Support parameters of LightGBM.